@@ -207,3 +207,15 @@ def server_websuite(user='webuser',python_version='3.4.2'):
 
 
     pass
+
+
+
+def server_mysql():
+    with settings(warn_only=True):
+        run('rpm -Uvh http://dev.mysql.com/get/mysql-community-release-el6-5.noarch.rpm')
+
+    run('yum install mysql-community-server -y')
+    run('chkconfig --level 35 mysqld on')
+    pass
+
+
